@@ -5,7 +5,7 @@ from .pixel import pixel
 from .ring import ring
 from .sunset import sunset
 
-__version__ = "0.3.1"
+__version__ = "0.3.2"
 
 __all__ = ["avatar"]
 
@@ -24,7 +24,7 @@ VARIANTS = {
 def avatar(
     name: str,
     *,
-    colors: [str] = DEFAULT_COLORS,
+    colors: list[str] = DEFAULT_COLORS,
     variant: str = "marble",
     title: bool = False,
     size: int = 40,
