@@ -1,11 +1,11 @@
-from .utils import get_random_color, get_unit, render
+from .utils import hash_code, get_random_color, get_unit, render
 
 SIZE = 90
 COLORS = 5
 
 
 def generate_colors(name, colors):
-    num_from_name = hash(name)
+    num_from_name = hash_code(name)
     colors_shuffle = [
         get_random_color(num_from_name + i, colors, len(colors)) for i in range(COLORS)
     ]
@@ -22,9 +22,16 @@ def generate_colors(name, colors):
     ]
 
 
-def ring(name, colors, square):
+def ring(name, *, colors, size, title, square):
     ring_colors = generate_colors(name, colors)
     return render(
         "ring.svg",
-        {"ring_colors": ring_colors, "SIZE": SIZE, "size": "80", "square": square},
+        {
+            "name": name,
+            "ring_colors": ring_colors,
+            "SIZE": SIZE,
+            "size": size,
+            "title": title,
+            "square": square,
+        },
     )
